==> fullscreen-0.1.3.tgz: package/src/index.js <==
/** Libraries **/
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

/** Function **/
import fscreen from './fullScreen';

export default class FullScreen extends PureComponent {
  constructor(props) {
    super(props);

    this.onFullScreen = this.onFullScreen.bind(this);
    this.onFullScreenChange = this.onFullScreenChange.bind(this);
    this.onExit = this.onExit.bind(this);

    this.fscreenRef = React.createRef();
  }

  componentDidMount() {
    fscreen.addEventListener('fullscreenchange', this.onFullScreenChange);
  }

  componentDidUpdate() {
    let isfscreenElement = fscreen.fullscreenElement === this.fscreenRef.current;
    if (isfscreenElement && !this.props.isEnabled) {
      this.onExit();
    } else if (!isfscreenElement && this.props.isEnabled) {
      this.onFullScreen();
    }
  }

  shouldComponentUpdate(nextProps) {
    return nextProps.isEnabled !== this.props.isEnabled;
  }

  onFullScreen() {
    fscreen.isFullscreenEnabled && fscreen.requestFullscreen(this.fscreenRef.current);
  }

  onExit() {
    fscreen.isFullscreenEnabled && fscreen.exitFullscreen();
  }

  onFullScreenChange() {
    let { onChange } = this.props;
    onChange && onChange(fscreen.fullscreenElement === this.fscreenRef.current);
  }

  componentWillUnmount() {
    fscreen.removeEventListener('fullscreenchange', this.onFullScreenChange);
    this.fscreenRef = null;
  }

  render() {
    let { isEnabled, className, children } = this.props;
    if (isEnabled) {
      className += ' fullscreenEnabled';
    }
    return (
      <div className={className} ref={this.fscreenRef}>
        {children}
      </div>
    );
  }
}

FullScreen.defaultProps = {
  isEnabled: false,
  className: ''
};

FullScreen.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isEnabled: PropTypes.bool.isRequired,
  onChange: PropTypes.func
};

==> fullscreen-0.1.4.tgz: package/src/index.js <==
/** Libraries **/
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

/** Function **/
import fscreen from './fullScreen';

// css
import style from './fullscreen.module.css'

export default class FullScreen extends PureComponent {
  constructor(props) {
    super(props);

    this.onFullScreen = this.onFullScreen.bind(this);
    this.onFullScreenChange = this.onFullScreenChange.bind(this);
    this.onExit = this.onExit.bind(this);

    this.fscreenRef = React.createRef();
  }

  componentDidMount() {
    fscreen.addEventListener('fullscreenchange', this.onFullScreenChange);
  }

  componentDidUpdate() {
    let isfscreenElement = fscreen.fullscreenElement === this.fscreenRef.current;
    if (isfscreenElement && !this.props.isEnabled) {
      this.onExit();
    } else if (!isfscreenElement && this.props.isEnabled) {
      this.onFullScreen();
    }
  }

  shouldComponentUpdate(nextProps) {
    return nextProps.isEnabled !== this.props.isEnabled;
  }

  onFullScreen() {
    fscreen.isFullscreenEnabled && fscreen.requestFullscreen(this.fscreenRef.current);
  }

  onExit() {
    fscreen.isFullscreenEnabled && fscreen.exitFullscreen();
  }

  onFullScreenChange() {
    let { onChange } = this.props;
    onChange && onChange(fscreen.fullscreenElement === this.fscreenRef.current);
  }

  componentWillUnmount() {
    fscreen.removeEventListener('fullscreenchange', this.onFullScreenChange);
    this.fscreenRef = null;
  }

  render() {
    let { isEnabled, className, children } = this.props;
    if (isEnabled) {
      className += ' fullscreenEnabled';
    }
    return (
      <div className={`${className} ${style.fullScreen}`} ref={this.fscreenRef}>
        {children}
      </div>
    );
  }
}

FullScreen.defaultProps = {
  isEnabled: false,
  className: ''
};

FullScreen.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isEnabled: PropTypes.bool.isRequired,
  onChange: PropTypes.func
};
